<script>
	// this code just close the window and returns the access token. This should ve change to
	// return the windows login status.
	window.returnValue = "{{ access_token }}";
	window.close();
</script>
